@@ -1,6 +1,6 @@
 package Net::Stomp::Producer;
 {
-  $Net::Stomp::Producer::VERSION = '1.5';
+  $Net::Stomp::Producer::VERSION = '1.6';
 }
 {
   $Net::Stomp::Producer::DIST = 'Net-Stomp-Producer';
@@ -93,7 +93,11 @@ sub make_transformer {
 
     load_class($transformer);
     if ($transformer->can('new')) {
-        return $transformer->new($self->transformer_args);
+        # shallow clone, to make it less likely that a transformer
+        # will clobber our args
+        return $transformer->new(
+            { %{$self->transformer_args} }
+        );
     }
     return $transformer;
 }
@@ -164,6 +168,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -174,7 +179,7 @@ Net::Stomp::Producer - helper object to send messages via Net::Stomp
 
 =head1 VERSION
 
-version 1.5
+version 1.6
 
 =head1 SYNOPSIS
 
@@ -423,4 +428,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
